## 17:114.11. so

Celkový čas 29 min, vzdálenost 11 km

### Bus 46

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 17:11

  Horní Polanka D 2

- 17:26

  Svinov,mosty õ D12

Přesun asi 2 min

### Tram 17

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 17:31

  Svinov,mosty õ= H1

- 17:40

  VŠB-TUO = 1

- Detaily spojení
- Vytisknout
- Sdílet(1)
- Zobrazit na mapě
- Přidat do Mých spojení

","

## 17:464.11. so

Celkový čas 27 min, vzdálenost 11 km

### Bus 46

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 17:46

  Horní Polanka D 2

- 18:01

  Svinov,mosty õ D12

Přesun asi 2 min

### Tram 7

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 18:04

  Svinov,mosty õ= H1

- 18:13

  VŠB-TUO = 1

- Detaily spojení
- Vytisknout
- Sdílet(1)
- Zobrazit na mapě
- Přidat do Mých spojení